@@ -1,4 +1,4 @@
-from models import Direction
+from . import Direction
 
 
 class Controls:
